# ASN.1 module CPM-CommonDataTypes-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) commonDataTypes (2) version1 (1) }_

## Imports:
 * **[ITS-Container](ITS-Container.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) version (2)}*<br/>
   Include ETSI TS 102 894-2 v1.3.1
   Include references from https://forge.etsi.org/rep/ITS/asn1/cdd_ts102894_2/blob/v1.3.1/ITS-Container.asn

 * **[DSRC](DSRC.md)** *{iso (1) standard (0) signalizedIntersection (19091) profilec(2) dsrc (2) version2 (2)}*<br/>
   Include ISO 19091
   Include references from https://standards.iso.org/iso/ts/19091/ed-2/en/ISO-TS-19091-addgrp-C-2018.asn

 * **[VAM-PDU-Descriptions](VAM-PDU-Descriptions.md)** *{itu-t(0) identified-organization(4) etsi(0) itsDomain(5) wg1(1) ts(103300) vam(1) version1(1)}*<br/>
   Include ETSI TS 103 300-3 V2.1.1
   Include references from https://forge.etsi.org/rep/ITS/asn1/vam-ts103300_3/tree/v2.1.1/

## Data Elements:
### <a name="AreaCircular"></a>AreaCircular

Area Circular
Describes a circular area. The circle is centred about the reference point of the ITS-S or about
the nodeCenterPoint (if provided). The DF shall include the following information:

Fields:
* nodeCenterPoint [**OffsetPoint**](#OffsetPoint)  OPTIONAL<br>

   Optional offset point about which the circle is centred with respect to the reference
   position of the ITS-S.
   
* radius [**Radius**](#Radius) <br>

   The radius of the circular area
   
```asn1
AreaCircular ::= SEQUENCE {
        nodeCenterPoint      OffsetPoint OPTIONAL,
        radius               Radius
}
```

### <a name="AreaEllipse"></a>AreaEllipse

Area Ellipse
Describes an elliptical area. The ellipse is centred about the reference point of the ITS-S or
about the nodeCenterPoint (if provided).

Fields:
* nodeCenterPoint [**OffsetPoint**](#OffsetPoint)  OPTIONAL<br>

   Optional offset point about which the ellipse is centred with respect to the reference
   position of the ITS-S.
   
* semiMinorRangeLength [**SemiRangeLength**](#SemiRangeLength) <br>

   Major radius of the ellipse.
   
* semiMajorRangeLength [**SemiRangeLength**](#SemiRangeLength) <br>

   Minor radius of the ellipse.
   
* semiMajorRangeOrientation [**WGS84AngleValue**](#WGS84AngleValue) <br>

   Orientation of the semiMajorRangeLength of the ellipse in the WGS84 coordinate system.
   
* semiHeight [**SemiRangeLength**](#SemiRangeLength)  OPTIONAL<br>
```asn1
AreaEllipse  ::= SEQUENCE {
        nodeCenterPoint             OffsetPoint OPTIONAL,
        semiMinorRangeLength        SemiRangeLength,
        semiMajorRangeLength        SemiRangeLength,
        semiMajorRangeOrientation   WGS84AngleValue,
    semiHeight                  SemiRangeLength OPTIONAL
}
```

### <a name="AreaRectangle"></a>AreaRectangle

Area Rectangle
Describes a rectangular area. The rectangle is centred about the reference point of the ITS-S or
about the nodeCenterPoint (if provided).

Fields:
* nodeCenterPoint [**OffsetPoint**](#OffsetPoint)  OPTIONAL<br>

   Optional offset point about which the rectangle is centred with respect to the reference
   position of the ITS-S.
   
* semiMajorRangeLength [**SemiRangeLength**](#SemiRangeLength) <br>

   Half length of the rectangle.
   
* semiMinorRangeLength [**SemiRangeLength**](#SemiRangeLength) <br>

   Half width of the rectangle.
   
* semiMajorRangeOrientation [**WGS84AngleValue**](#WGS84AngleValue) <br>

   Orientation of the semiMajorRangeLength of the rectangle in the WGS84 coordinate system.
   
* semiHeight [**SemiRangeLength**](#SemiRangeLength)  OPTIONAL<br>
```asn1
AreaRectangle ::= SEQUENCE {
        nodeCenterPoint             OffsetPoint OPTIONAL,
        semiMajorRangeLength        SemiRangeLength,
        semiMinorRangeLength        SemiRangeLength,
        semiMajorRangeOrientation   WGS84AngleValue,
    semiHeight                  SemiRangeLength OPTIONAL
}
```

### <a name="AreaPolygon"></a>AreaPolygon

Area Polygon
Describes a polygonal area constructed by connecting the offset points in the sequence
provided. The last point shall be connected with the first point to close the polygon.

Fields:
* polyPointList [**PolyPointList**](#PolyPointList) <br>
```asn1
AreaPolygon ::= SEQUENCE {
    polyPointList   PolyPointList
}
```

### <a name="PolyPointList"></a>PolyPointList

Poly Point List
Describes a list of points representing a polygon. The last point shall be connected with the
first point to close the polygon.


```asn1
PolyPointList ::= SEQUENCE (SIZE(3..16, ...)) OF OffsetPoint
```

### <a name="AreaRadial"></a>AreaRadial

Area Radial
Describes a radial area scanned by a stationary sensor. The triangular or cone-shaped area is
constructed by sweeping the provided range about the reference point of the ITS-S or about the
point described by the sensor offset point (if provided) with respect to the reference point
between a horizontal start and a horizontal end angle in positive angular direction of the WGS84
coordinate system. A vertical opening angle may be provided in a Cartesian coordinate system with
the x-axis located in the North-East plane of the WGS84 coordinate system. The sensor height may
be provided to reflect characteristics of sensors mounted at an altitude (e.g. sensors mounted
above intersections).

Fields:
* range [**Range**](#Range) <br>

   The radial range of the sensor from the reference point or sensor point offset.
   
* stationaryHorizontalOpeningAngleStart [**WGS84AngleValue**](#WGS84AngleValue) <br>

   The orientation indicating the beginning of the stationary sensor’s horizontal opening angle
   in positive angular direction with respect to the WGS84 coordinate system.
   
* stationaryHorizontalOpeningAngleEnd [**WGS84AngleValue**](#WGS84AngleValue) <br>

   The orientation indicating the end of the stationary sensor’s horizontal opening angle in
   positive angular direction with respect to the WGS84 coordinate system.
   
* verticalOpeningAngleStart [**CartesianAngleValue**](#CartesianAngleValue)  OPTIONAL<br>

   The orientation indicating the beginning of the stationary sensor’s vertical opening angle in
   positive angular direction of a Cartesian coordinate system with its x-axis located in the
   north-east plane of the WGS84 coordinate system.
   
* verticalOpeningAngleEnd [**CartesianAngleValue**](#CartesianAngleValue)  OPTIONAL<br>

   The orientation indicating the end of the stationary sensor’s vertical opening angle in
   positive angular direction of a Cartesian coordinate system with its x-axis located in the
   north-east plane of the WGS84 coordinate system.
   
* sensorPositionOffset [**OffsetPoint**](#OffsetPoint)  OPTIONAL<br>

   The offset of the mounting poinf of this sensor from the station's @see ReferencePosition.
   
* sensorHeight [**SensorHeight**](#SensorHeight)  OPTIONAL<br>

   The height of the sensor mounting point.
   
```asn1
AreaRadial ::= SEQUENCE {
        range                                   Range,
        stationaryHorizontalOpeningAngleStart   WGS84AngleValue,
        stationaryHorizontalOpeningAngleEnd     WGS84AngleValue,
        verticalOpeningAngleStart               CartesianAngleValue OPTIONAL,
        verticalOpeningAngleEnd                 CartesianAngleValue OPTIONAL,
        sensorPositionOffset                    OffsetPoint OPTIONAL,
        sensorHeight                            SensorHeight OPTIONAL,
    ...
}
```

### <a name="ObjectDistance"></a>ObjectDistance

Object Distance With Confidence
A general Data Frame to describe a distance component along with a confidence with a
predefined confidence level of 95% for the component.

Fields:
* value [**DistanceValue**](#DistanceValue) <br>

   The distance value which can be estimated as the mean of the current distribution.
   
* confidence [**DistanceConfidence**](#DistanceConfidence) <br>

   The distance accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
ObjectDistance ::= SEQUENCE {
        value        DistanceValue,
        confidence   DistanceConfidence
}
```

### <a name="ObjectDimension"></a>ObjectDimension

Object Dimension
A general Data Frame to describe a dimension of an object along with a confidence with a
predefined confidence level of 95% for the component.

Fields:
* value [**ObjectDimensionValue**](#ObjectDimensionValue) <br>

   The object dimension value which can be estimated as the mean of the current distribution.
   
* confidence [**ObjectDimensionConfidence**](#ObjectDimensionConfidence) <br>

   The dimension accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
ObjectDimension ::= SEQUENCE {
        value       ObjectDimensionValue,
        confidence  ObjectDimensionConfidence
}
```

### <a name="CartesianAngle"></a>CartesianAngle

Cartesian Angle
A general Data Frame to describe an angle component along with a confidence with a predefined
confidence level of 95% for the component in a Cartesian coordinate system.

Fields:
* value [**CartesianAngleValue**](#CartesianAngleValue) <br>

   The angle value which can be estimated as the mean of the current distribution.
   
* confidence [**AngleConfidence**](#AngleConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
CartesianAngle ::= SEQUENCE {
        value       CartesianAngleValue,
        confidence  AngleConfidence
}
```

### <a name="CartesianAngularSpeed"></a>CartesianAngularSpeed

CartesianAngularSpeed
A general Data Frame to describe an angular speed component along with a confidence with a predefined
confidence level of 95% for the component in a Cartesian coordinate system.

Fields:
* value [**CartesianAngularSpeedValue**](#CartesianAngularSpeedValue) <br>

   The angular speed (rate) value which can be estimated as the mean of the current distribution.
   
* confidence [**AngularSpeedConfidence**](#AngularSpeedConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
CartesianAngularSpeed ::= SEQUENCE {
        value       CartesianAngularSpeedValue,
        confidence  AngularSpeedConfidence
}
```

### <a name="CartesianAngularAcceleration"></a>CartesianAngularAcceleration

CartesianAngularAcceleration
A general Data Frame to describe an angular acceleration component along with a confidence with a predefined
confidence level of 95% for the component in a Cartesian coordinate system.

Fields:
* value [**CartesianAngularAccelerationValue**](#CartesianAngularAccelerationValue) <br>

   The angular acceleration value which can be estimated as the mean of the current distribution.
   
* confidence [**AngularAccelerationConfidence**](#AngularAccelerationConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
CartesianAngularAcceleration ::= SEQUENCE {
        value       CartesianAngularAccelerationValue,
        confidence  AngularAccelerationConfidence
}
```

### <a name="WGS84Angle"></a>WGS84Angle

WGS 84 Angle
A general Data Frame to describe an angular component along with a confidence with a predefined
confidence level of 95% for the component in the WGS84 coordinate system.

Fields:
* value [**WGS84AngleValue**](#WGS84AngleValue) <br>

   The angle value which can be estimated as the mean of the current distribution.
   
* confidence [**AngleConfidence**](#AngleConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
WGS84Angle ::= SEQUENCE {
        value       WGS84AngleValue,
        confidence  AngleConfidence
}
```

### <a name="SpeedExtended"></a>SpeedExtended

Speed Extended
A general Data Frame to describe a speed component along with a confidence with a predefined
confidence level of 95% for the component.

Fields:
* value [**SpeedValueExtended**](#SpeedValueExtended) <br>

   The speed value which can be estimated as the mean of the current distribution.
   
* confidence [**SpeedConfidence**](ITS-Container.md#SpeedConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
SpeedExtended ::= SEQUENCE {
        value       SpeedValueExtended,
        confidence  SpeedConfidence
}
```

### <a name="Acceleration"></a>Acceleration

Acceleration
A general Data Frame to describe an acceleration component along with a confidence with a predefined
confidence level of 95% for the component.

Fields:
* value [**AccelerationValue**](#AccelerationValue) <br>

   The acceleration value which can be estimated as the mean of the current distribution.
   
* confidence [**AccelerationConfidence**](ITS-Container.md#AccelerationConfidence) <br>

   The accuracy associated to the provided value at a predefined confidence level
   of 95% for the component.
   
```asn1
Acceleration ::= SEQUENCE {
        value       AccelerationValue,
        confidence  AccelerationConfidence
}
```

### <a name="SensorIdList"></a>SensorIdList

Sensor ID List
List of sensor IDs.


```asn1
SensorIdList ::= SEQUENCE SIZE(1..128, ...) OF Identifier
```

### <a name="TrailerDataContainer"></a>TrailerDataContainer

Trailer Data Container
List of information about attached trailers.


```asn1
TrailerDataContainer ::= SEQUENCE SIZE(1..2) OF TrailerData
```

### <a name="TrailerData"></a>TrailerData

Trailer Data
Provides detailed information about the dimensions and orientation of an attached trailer.

Fields:
* refPointId [**RefPointId**](#RefPointId) <br>
* hitchPointOffset [**HitchPointOffset**](#HitchPointOffset) <br>
* frontOverhang [**FrontOverhang**](#FrontOverhang) <br>
* rearOverhang [**RearOverhang**](#RearOverhang) <br>
* trailerWidth [**VehicleWidth**](ITS-Container.md#VehicleWidth)  OPTIONAL<br>
* hitchAngle [**CartesianAngle**](#CartesianAngle)  OPTIONAL<br>
```asn1
TrailerData ::= SEQUENCE {
    refPointId          RefPointId,
    hitchPointOffset    HitchPointOffset,
    frontOverhang       FrontOverhang,
    rearOverhang        RearOverhang,
    trailerWidth        VehicleWidth OPTIONAL,
    hitchAngle          CartesianAngle OPTIONAL,
    ...
}
```

### <a name="MatchedPosition"></a>MatchedPosition

Matched Position
Indicates the position of the object mapped on the intersection topology description transmitted
in MAP messages.

Fields:
* laneID [**LaneID**](DSRC.md#LaneID)  OPTIONAL<br>

   Conveys an assigned index that is unique within the intersection with InterSectionReferenceId
   of the OriginatingRSUContainer. It shall be presented as specified in
   Clause 7.88 of SAE J2735.
   
* longitudinalLanePosition [**LongitudinalLanePosition**](#LongitudinalLanePosition)  OPTIONAL<br>

   Indicates the longitudinal offset of the map-matched position of the object along the lane.
   
```asn1
MatchedPosition ::= SEQUENCE {
        laneID                      LaneID OPTIONAL,
        longitudinalLanePosition    LongitudinalLanePosition OPTIONAL,
    ...
}
```

### <a name="LongitudinalLanePosition"></a>LongitudinalLanePosition

Longitudinal Lane Position
Estimated position along the longitudinal length of a particular lane. A lane is provided by
a corresponding MAP message.

Fields:
* longitudinalLanePositionValue [**LongitudinalLanePositionValue**](#LongitudinalLanePositionValue) <br>

   The mean value of the longitudinal position within a particular length.
   
* longitudinalLanePositionConfidence [**LongitudinalLanePositionConfidence**](#LongitudinalLanePositionConfidence) <br>

   The confidence associated to the provided value.
   
```asn1
LongitudinalLanePosition ::= SEQUENCE {
        longitudinalLanePositionValue        LongitudinalLanePositionValue,
        longitudinalLanePositionConfidence   LongitudinalLanePositionConfidence
}
```

### <a name="MessageSegmentInfo"></a>MessageSegmentInfo

Message Segment Information
Information about segmented CPM and the number of generated segments.

Fields:
* totalMsgSegments [**SegmentCount**](#SegmentCount) <br>

   The total number of messages required on the transmitter side to distribute the information
   to several messages.
   
* thisSegmentNum [**SegmentCount**](#SegmentCount) <br>

   Indicates the number of the received message out of the total number of messages
   used to realize segmentation.
   
```asn1
MessageSegmentInfo ::= SEQUENCE {
        totalMsgSegments    SegmentCount,
        thisSegmentNum      SegmentCount
}
```

### <a name="LowerTriangularPositiveSemidefiniteMatrix"></a>LowerTriangularPositiveSemidefiniteMatrix

Lower Triangular Positive Semi-Definite Matrix
A general data frame to express the elements of a lower triangular positive semi-definite matrix, not
including the main diagonal elements of the matrix.
Given a matrix "A" of size n x n, the number of columns to be included in the lower triangular matrix is k=n-1.


```asn1
LowerTriangularPositiveSemidefiniteMatrix ::= SEQUENCE SIZE (1..17) OF CorrelationColumn
```

### <a name="CorrelationColumn"></a>CorrelationColumn

Correlation Column
The column of the lower triangular positive semi-definite matrix consists of correlation row values.
Given a matrix "A" of size n x n, the number of columns to be included in the lower triangular matrix is k=n-1.
Each column "i" of the lower triangular then contains k-(i-1) values, where "i" refers to the column number count
starting at 1 from the left.


```asn1
CorrelationColumn ::= SEQUENCE SIZE (1..17) OF CorrelationRowValue
```

### <a name="CorrelationRowValue"></a>CorrelationRowValue

Correlation Row Value
The Bravais-Pearson correlation value for each cell of the lower triangular correlation matrix.
Scaled by 100.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _None_

Values:
* **full-negative-correlation** (-100)<br>
   Full negative correlation
* **no-correlation** (0)<br>
   If not correlated or unavailable
* **point-one** (10)<br>
* **full-positive-correlation** (100)       <br>
   Full positive correlation
```asn1
CorrelationRowValue ::= INTEGER {
    full-negative-correlation    (-100),     
    no-correlation               (0),        
    point-one                    (10),
    full-positive-correlation    (100)       
} (-100..100)
```

### <a name="ObjectClassDescription"></a>ObjectClassDescription

Object Class Description
A list of object classes.


```asn1
ObjectClassDescription ::= SEQUENCE (SIZE(1..8)) OF ObjectClassWithConfidence
```

### <a name="ObjectClassWithConfidence"></a>ObjectClassWithConfidence

Object Class with Confidence
Describes the classification of a detected object. The classification is provided with a
confidence indication.

Fields:
* objectClass [**ObjectClass**](#ObjectClass) <br>
* confidence [**ClassConfidence**](#ClassConfidence) <br>
```asn1
ObjectClassWithConfidence ::= SEQUENCE {
    objectClass ObjectClass,
    confidence  ClassConfidence
}
```

### <a name="ObjectClass"></a>ObjectClass

Object Class
The class that best describes the detected object. The object can be classified into one of three
categories: vehicle, VRU and other. Each class provides optional subclasses.

Fields:
* vehicleSubclass [**VehicleSubclassType**](#VehicleSubclassType) <br>
* vruSubclass [**VruSubclassType**](#VruSubclassType) <br>
* otherSubclass [**OtherSubclassType**](#OtherSubclassType) <br>
```asn1
ObjectClass ::= CHOICE {
    vehicleSubclass    VehicleSubclassType,
    vruSubclass        VruSubclassType,
    otherSubclass      OtherSubclassType,
    ...
}
```

### <a name="VruSubclassType"></a>VruSubclassType

VRU Subclass Type
Describes if a detected object is a single VRU or a group of VRUs.

Fields:
* singleVru [**VruProfileAndSubprofile**](VAM-PDU-Descriptions.md#VruProfileAndSubprofile) <br>
* vruGroupSubclass [**VruGroupSubClassType**](#VruGroupSubClassType) <br>
```asn1
VruSubclassType ::= CHOICE {
    singleVru           VruProfileAndSubprofile,
    vruGroupSubclass    VruGroupSubClassType
}
```

### <a name="VruGroupSubClassType"></a>VruGroupSubClassType

VruGroup Subclass Type
Describes the composition of a group of VRUs.

Fields:
* groupType [**ClusterProfiles**](VAM-PDU-Descriptions.md#ClusterProfiles) <br>

   Indicates the profiles of the VRUs detected in the group.
   A group of VRUs may be composed of VRUs of several different profiles.
   
* groupSize [**ClusterCardinalitySize**](VAM-PDU-Descriptions.md#ClusterCardinalitySize) <br>

   Indicates an estimation of the number of VRUs in the group.
   
* clusterID [**ClusterId**](VAM-PDU-Descriptions.md#ClusterId)  OPTIONAL<br>

   If the group is associated to a VRU cluster, this element indicates the ID of the associated cluster.
   The ClusterId can only be assigned if a VRU cluster which is transmitting VAMs has been detected.
   
```asn1
VruGroupSubClassType ::= SEQUENCE {
        groupType   ClusterProfiles,
        groupSize   ClusterCardinalitySize,
        clusterID   ClusterId OPTIONAL
}
```

### <a name="OffsetPoint"></a>OffsetPoint

Offset Point
Describes an offset position in a two- or three-dimensional plane as imported from
CEN ISO/TS 19091. Excludes the node-LatLon DF and regional DF defined therein.

Fields:
* nodeOffsetPointxy [**NodeOffsetPointXY**](DSRC.md#NodeOffsetPointXY)  (WITH COMPONENTS {..., node-LatLon ABSENT, regional ABSENT})<br>
* nodeOffsetPointZ [**NodeOffsetPointZ**](#NodeOffsetPointZ)  OPTIONAL<br>
```asn1
OffsetPoint ::= SEQUENCE{
    nodeOffsetPointxy   NodeOffsetPointXY (WITH COMPONENTS {..., node-LatLon ABSENT, regional ABSENT}),
    nodeOffsetPointZ    NodeOffsetPointZ OPTIONAL
}
```

### <a name="NodeOffsetPointZ"></a>NodeOffsetPointZ

Node Offset Point in Z-direction
Describes the vertical offset from another point. This is specified in close resemblance
to SAE J2735 _NodeOffsetPointXY_.

Fields:
* node-Z1 [**Offset-B10**](DSRC.md#Offset-B10) <br>
   node is within 5.11m of last node
* node-Z2 [**Offset-B11**](DSRC.md#Offset-B11) <br>
   node is within 10.23m of last node
* node-Z3 [**Offset-B12**](DSRC.md#Offset-B12) <br>
   node is within 20.47m of last node
* node-Z4 [**Offset-B13**](DSRC.md#Offset-B13) <br>
   node is within 40.96m of last node
* node-Z5 [**Offset-B14**](DSRC.md#Offset-B14) <br>
   node is within 81.91m of last node
* node-Z6 [**Offset-B16**](DSRC.md#Offset-B16)   <br>
   node is within 327.67m of last node
```asn1
NodeOffsetPointZ ::= CHOICE {
    node-Z1 Offset-B10, 
    node-Z2 Offset-B11, 
    node-Z3 Offset-B12, 
    node-Z4 Offset-B13, 
    node-Z5 Offset-B14, 
    node-Z6 Offset-B16  
}
```

### <a name="VehicleSubclassType"></a>VehicleSubclassType

Vehicle Subclass Type
Describes the subclass of a detected object for class vehicle.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **unknown** (0)<br>
   the type of vehicle is unknown
* **passengerCar** (1)<br>
   the detected object is a small passenger car as defined in
   UNECE/TRANS/WP.29/78/Rev.4 class M1
* **bus** (2)<br>
   the detected object is a large passenger vehicle as defined
   in UNECE/TRANS/WP.29/78/Rev.4 class M2, M3
* **lightTruck** (3)<br>
   the detected object is a light goods vehicle as defined
   in UNECE/TRANS/WP.29/78/Rev.4 class N1
* **heavyTruck** (4)<br>
   the detected object is a heavy goods vehicle as defined
   in UNECE/TRANS/WP.29/78/Rev.4 class N2, N3
* **trailer** (5)<br>
   the detected object is an unpowered vehicle that is intended
   to be towed by a powered vehicle as defined in
   UNECE/TRANS/WP.29/78/Rev.4 class O
* **specialVehicles** (6)<br>
   the detected object is a vehicle which has a special purpose
   other than the above (e.g. moving road works vehicle)
* **tram** (7)<br>
   the detected object is a vehicle running on tracks along
   public streets
* **emergencyVehicle** (8)<br>
   the detected object is a vehicle used in an emergency situation
   such as an ambulance, police car or fire engine
* **agricultural** (9)     <br>
   the detected object is a vehicle used for agricultural purposes
```asn1
VehicleSubclassType ::= INTEGER {
    unknown             (0),    
    passengerCar        (1),    
    bus                 (2),    
    lightTruck          (3),    
    heavyTruck          (4),    
    trailer             (5),    
    specialVehicles     (6),    
    tram                (7),    
    emergencyVehicle    (8),    
    agricultural        (9)     
} (0..255)
```

### <a name="OtherSubclassType"></a>OtherSubclassType

Other Subclass Type
Describes the subclass of a detected object for class other.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **unknown** (0)<br>
* **roadSideUnit** (1)<br>
```asn1
OtherSubclassType ::= INTEGER {
    unknown         (0),
    roadSideUnit    (1)
} (0..255)
```

### <a name="ClassConfidence"></a>ClassConfidence

Class Confidence
Describes the confidence value for the type of a detected object.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _Percent_

Values:
* **unknown** (0)<br>
   in case the confidence value is unknown but the reported
   classification is still valid.
* **onePercent** (1)<br>
* **oneHundredPercent** (100)<br>
* **unavailable** (101)   <br>
   In case the class confidence value computation is not available
   for this object. Indicates that the class assignment is invalid.
```asn1
ClassConfidence ::= INTEGER {
    unknown             (0),    
    onePercent          (1),
    oneHundredPercent   (100),
    unavailable         (101)   
} (0..101)
```

### <a name="WGS84AngleValue"></a>WGS84AngleValue

WGS 84 Angle Value
An angle value in degrees described in the WGS84 reference system with respect to the WGS84 north.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 degrees_

Values:
* **wgs84North** (0)<br>
* **wgs84East** (900)<br>
* **wgs84South** (1800)<br>
* **wgs84West** (2700)<br>
* **unavailable** (3601)<br>
```asn1
WGS84AngleValue ::= INTEGER {
    wgs84North          (0),
    wgs84East           (900),
    wgs84South          (1800),
    wgs84West           (2700),
    unavailable         (3601)
} (0..3601)
```

### <a name="CartesianAngleValue"></a>CartesianAngleValue

Cartesian Angle Value
An angle value described in a local Cartesian coordinate system, counted positive in
a right-hand local coordinate system from the abscissa.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 degrees_

Values:
* **zeroPointOneDegree** (1)<br>
* **oneDegree** (10)<br>
* **unavailable** (3601)<br>
```asn1
CartesianAngleValue ::= INTEGER {
    zeroPointOneDegree  (1),
    oneDegree           (10),
    unavailable         (3601)
} (0..3601)
```

### <a name="CartesianAngularSpeedValue"></a>CartesianAngularSpeedValue

Cartesian Angular Speed Value
An angular speed value described in a local Cartesian coordinate system, counted positive in
a right-hand local coordinate system from the abscissa.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 degrees/s_

Values:
* **noSpeed** (0)<br>
* **oneDegreePerSecondAntiClockwise** (100)<br>
* **oneDegreePerSecondClockwise** (-100)<br>
```asn1
CartesianAngularSpeedValue ::= INTEGER {
    noSpeed                             (0),
    oneDegreePerSecondAntiClockwise     (100),
    oneDegreePerSecondClockwise         (-100)
} (-32766..32767)
```

### <a name="CartesianAngularAccelerationValue"></a>CartesianAngularAccelerationValue

Cartesian Angular Acceleration Value
An angular acceleration value described in a local Cartesian coordinate system, counted positive in
a right-hand local coordinate system from the abscissa.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 degrees/s^2 (degrees per second squared)_

Values:
* **noAcceleration** (0)<br>
* **oneDegreePerSecondSquaredAntiClockwise** (100)<br>
* **oneDegreePerSecondSquaredClockwise** (-100)<br>
```asn1
CartesianAngularAccelerationValue ::= INTEGER {
    noAcceleration                             (0),
    oneDegreePerSecondSquaredAntiClockwise     (100),
    oneDegreePerSecondSquaredClockwise         (-100)
} (-32766..32767)
```

### <a name="AngleConfidence"></a>AngleConfidence

Angle Confidence
The absolute accuracy of a reported angle value for a predefined confidence level (e.g. 95 %).
The required confidence level is defined by the corresponding standards applying this DE.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 degrees_

Values:
* **zeroPointOneDegree** (1)<br>
* **oneDegree** (10)<br>
* **outOfRange** (126)<br>
   if the  accuracy is out of range, i.e. greater than
   12,5 degrees. A corresponding reported angle value shall be
   considered invalid and cannot be trusted.
* **unavailable** (127)   <br>
   if the accuracy information is not available
```asn1
AngleConfidence ::= INTEGER {
    zeroPointOneDegree  (1),
    oneDegree           (10),
    outOfRange          (126),  
    unavailable         (127)   
} (1..127)
```

### <a name="AngularSpeedConfidence"></a>AngularSpeedConfidence

Angular Speed Confidence
The absolute accuracy of a reported angular speed value for a predefined confidence level (e.g. 95 %).
The required confidence level is defined by the corresponding standards applying this DE.
For correlation computation, maximum interval levels shall be assumed.
@ n/a

Values:
* **degSec-000-01** (0)<br>
   if the accuracy is equal to or less than 0,01 degree/second
* **degSec-000-05** (1)<br>
   1 if the accuracy is equal to or less than 0,05 degrees/second
* **degSec-000-10** (2)<br>
   if the accuracy is equal to or less than 0,1 degree/second
* **degSec-001-00** (3)<br>
   3 if the accuracy is equal to or less than 1 degree/second
* **degSec-005-00** (4)<br>
   if the accuracy is equal to or less than 5 degrees/second
* **degSec-010-00** (5)<br>
   if the accuracy is equal to or less than 10 degrees/second
* **degSec-100-00** (6)<br>
   if the accuracy is equal to or less than 100 degrees/second
* **outOfRange** (7)<br>
   if the accuracy is out of range, i.e. greater than 100 degrees/second
* **unavailable** (8)     <br>
   if the accuracy information is unavailable
```asn1
AngularSpeedConfidence ::= ENUMERATED {
    degSec-000-01 (0),  
    degSec-000-05 (1),  
    degSec-000-10 (2),  
    degSec-001-00 (3),  
    degSec-005-00 (4),  
    degSec-010-00 (5),  
    degSec-100-00 (6),  
    outOfRange (7),     
    unavailable (8)     
}
```

### <a name="AngularAccelerationConfidence"></a>AngularAccelerationConfidence

Angular Acceleration Confidence
The absolute accuracy of a reported angular acceleration value for a predefined confidence level (e.g. 95 %).
The required confidence level is defined by the corresponding standards applying this DE.
For correlation computation, maximum interval levels shall be assumed.
@ n/a

Values:
* **degSecSquared-000-01** (0)<br>
   if the accuracy is equal to or less than 0,01 degree/second^2
* **degSecSquared-000-05** (1)<br>
   1 if the accuracy is equal to or less than 0,05 degrees/second^2
* **degSecSquared-000-10** (2)<br>
   if the accuracy is equal to or less than 0,1 degree/second^2
* **degSecSquared-001-00** (3)<br>
   3 if the accuracy is equal to or less than 1 degree/second^2
* **degSecSquared-005-00** (4)<br>
   if the accuracy is equal to or less than 5 degrees/second^2
* **degSecSquared-010-00** (5)<br>
   if the accuracy is equal to or less than 10 degrees/second^2
* **degSecSquared-100-00** (6)<br>
   if the accuracy is equal to or less than 100 degrees/second^2
* **outOfRange** (7)<br>
   if the accuracy is out of range, i.e. greater than 100 degrees/second^2
* **unavailable** (8)     <br>
   if the accuracy information is unavailable
```asn1
AngularAccelerationConfidence ::= ENUMERATED {
    degSecSquared-000-01 (0),  
    degSecSquared-000-05 (1),  
    degSecSquared-000-10 (2),  
    degSecSquared-001-00 (3),  
    degSecSquared-005-00 (4),  
    degSecSquared-010-00 (5),  
    degSecSquared-100-00 (6),  
    outOfRange (7),     
    unavailable (8)     
}
```

### <a name="SemiRangeLength"></a>SemiRangeLength

Semi Range Length
The length of an axis of an ellipsoid or rectangle, used to describe the extension in a
particular direction.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
SemiRangeLength ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10)
} (0..10000)
```

### <a name="DistanceValue"></a>DistanceValue

Distance Value
Distance from one point to another.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
```asn1
DistanceValue ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100)
} (-132768..132767)
```

### <a name="DistanceConfidence"></a>DistanceConfidence

Distance Confidence
Absolute accuracy of measurement to a confidence level of 95%.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
* **outOfRange** (4094)<br>
   shall be set if the accuracy is out of range
* **unavailable** (4095)   <br>
   shall be set if the accuracy data is unavailable
```asn1
DistanceConfidence ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100),
    outOfRange              (4094),  
    unavailable             (4095)   
} (0..4095)
```

### <a name="DynamicStatus"></a>DynamicStatus

Dynamic Status
Indication whether the detected object is classified as a dynamic (i.e. moving) object.
This value indicates whether an object has the general capability to move, i.e. change its
position.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **dynamic** (0)<br>
   the object is moving
* **hasBeenDynamic** (1)<br>
   indicates whether an object has been dynamic before, e.g., a car
   stopping at a traffic light
* **static** (2)     <br>
   shall be used in case an object is identified to be not moving
   throughout any previous observation
```asn1
DynamicStatus ::= INTEGER {
    dynamic             (0),    
    hasBeenDynamic      (1),    
    static              (2)     
} (0..2)
```

### <a name="HitchPointOffset"></a>HitchPointOffset

Hitch Point Offset
Position of the hitch point in negative x-direction (according to ISO 8855) from the
vehicle Reference Point.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
* **outOfRange** (254)<br>
* **unavailable** (255)<br>
```asn1
HitchPointOffset ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10),
    outOfRange          (254),
    unavailable         (255)
} (0..255)
```

### <a name="FrontOverhang"></a>FrontOverhang

Front Overhang
Length of the trailer overhang in the positive x direction (according to ISO 8855) from the
trailer Reference Point indicated by the refPointID. The value defaults to 0 in case the trailer
is not overhanging to the front with respect to the trailer reference point.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **noOverhang** (0)<br>
   trailer is not overhanging to the front with respect to the
   trailer reference point
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
FrontOverhang ::= INTEGER {
    noOverhang          (0),    
    zeroPointOneMeter   (1),
    oneMeter            (10)
} (0..50)
```

### <a name="FreeSpaceConfidence"></a>FreeSpaceConfidence

Free Space Confidence
Confidence indicating that an area is not occupied by a traffic participant or obstacle.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **unknown** (0)<br>
   if the free space confidence is unknown for the described area
* **onePercent** (1)<br>
* **oneHundredPercent** (100)<br>
* **unavailable** (101)   <br>
   if the confidence could not be computed and does not apply.
```asn1
FreeSpaceConfidence ::= INTEGER {
    unknown             (0),    
    onePercent          (1),
    oneHundredPercent   (100),
    unavailable         (101)   
} (0..101)
```

### <a name="LongitudinalLanePositionValue"></a>LongitudinalLanePositionValue

Longitudinal Lane Position Value
Indicates the longitudinal offset of the map-matched position of a particular object along the
matched lane, beginning from the lane’s starting point as defined in CEN ISO/TS 19091
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
```asn1
LongitudinalLanePositionValue ::= INTEGER {
    zeroPointOneMeter   (1)
} (0..32767)
```

### <a name="LongitudinalLanePositionConfidence"></a>LongitudinalLanePositionConfidence

Longitudinal Lane Position Confidence
Absolute accuracy of longitudinal lane position measurement to a confidence level of 95%.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
* **outOfRange** (101)<br>
   shall be set if the accuracy is out of range
* **unavailable** (102)   <br>
   shall be set if the accuracy data is unavailable
```asn1
LongitudinalLanePositionConfidence ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100),
    outOfRange              (101),  
    unavailable             (102)   
} (0..102)
```

### <a name="ObjectAge"></a>ObjectAge

Object Age
Age of object in milliseconds, i.e. for how long the object has been observed by the
disseminating station.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 ms_

Values:
* **oneMiliSec** (1)<br>
* **moreThan1Point5Second** (1500)  <br>
   indicates that the object has been observed for more than 1.5s.
```asn1
ObjectAge ::= INTEGER {
    oneMiliSec              (1),
    moreThan1Point5Second   (1500)  
} (0..1500)
```

### <a name="ObjectConfidence"></a>ObjectConfidence

Object Confidence
A single-value indication about the overall information quality of a perceived object. Its computation
is based on several scaling factors and moving averages. See Clause 7.6.4 of ETSI TS 103 324 for details
on the computation.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **noConfidence** (0)<br>
   No confidence in detected object, e.g. for "ghost"-objects or
   if confidence could not be computed
* **fullConfidence** (15)    <br>
   Full confidence in detected object
```asn1
ObjectConfidence ::= INTEGER {
    noConfidence        (0),    
    fullConfidence      (15)    
} (0..15)
```

### <a name="ObjectDimensionValue"></a>ObjectDimensionValue

Object Dimension Value
A dimension for an object.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
ObjectDimensionValue ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10)
} (0..1023)
```

### <a name="ObjectDimensionConfidence"></a>ObjectDimensionConfidence

Object Dimension Confidence
Accuracy of provided dimension value with a predefined confidence level (e.g. 95%)
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
* **outOfRange** (101)<br>
* **unavailable** (102)<br>
```asn1
ObjectDimensionConfidence ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100),
    outOfRange              (101),
    unavailable             (102)
} (0..102)
```

### <a name="ObjectRefPoint"></a>ObjectRefPoint

Object Reference Point
Reference point of measurement for the object dimensions. All provided state variables of this
object are given relative to the reference point. The point is included in the plane
perpendicular to the direction of the @see yawAngleValue.

Values:
* **mid** (0)<br>
* **bottomLeft** (1)<br>
* **midLeft** (2)<br>
* **topLeft** (3)<br>
* **bottomMid** (4)<br>
* **topMid** (5)<br>
* **bottomRight** (6)<br>
* **midRight** (7)<br>
* **topRight** (8)<br>
```asn1
ObjectRefPoint ::= INTEGER {
    mid             (0),
    bottomLeft      (1),
    midLeft         (2),
    topLeft         (3),
    bottomMid       (4),
    topMid          (5),
    bottomRight     (6),
    midRight        (7),
    topRight        (8)
} (0..8)
```

### <a name="Radius"></a>Radius

Radius
The dimension of a sensor area in the shape of a circle or a rectangle.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
Radius ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10)
}  (0..10000)
```

### <a name="Range"></a>Range

Range
Range of sensor within the indicated azimuth Angle defined by the start and end opening angle.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
Range ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10)
} (0..10000)
```

### <a name="RearOverhang"></a>RearOverhang

Rear Overhang
Length of the trailer overhang in the negative x direction (according to ISO 8855) from the
trailer Reference Point indicated by the @see refPointID
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m_

Values:
* **zeroPointOneMeter** (1)<br>
* **oneMeter** (10)<br>
```asn1
RearOverhang ::= INTEGER {
    zeroPointOneMeter   (1),
    oneMeter            (10)
    } (0..150)
```

### <a name="RefPointId"></a>RefPointId

Reference Point ID
Reference point counter for a trailer.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_



```asn1
RefPointId ::= INTEGER (0..255)
```

### <a name="SensorHeight"></a>SensorHeight

Sensor Height
Height of sensor position relative to altitude provided by the reference position.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
```asn1
SensorHeight ::= INTEGER  {
    zeroPointZeroOneMeter   (1)
} (-5000..5000)
```

### <a name="VehicleHeight"></a>VehicleHeight

Vehicle Height
The height if the vehicle, measured from the ground to the highest point, excluding any antennas.
In case vehicles are equipped with adjustable ride heights, camper shells, and any other
equipment which may result in varying height, the largest possible height shall be used.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _5 cm (DE ranges to 6.35 m)_



```asn1
VehicleHeight ::= INTEGER (0..127)
```

### <a name="ShadowingApplies"></a>ShadowingApplies

Shadowing Applies Indication
Boolean indication if tracing approach shall be used to compute a shadowed area behind an object.
If set to TRUE, the simple tracing approach shall be applied for each object intersecting or
located within the area or volume described by the freeSpaceAddendum container. If set to FALSE,
the simple tracing approach shall not be applied for each object intersecting or located within
the area or volume described by the freeSpaceAddenum container.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_



```asn1
ShadowingApplies ::= BOOLEAN
```

### <a name="Identifier"></a>Identifier

Identifier
General identifier data element.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_



```asn1
Identifier ::= INTEGER (0..255)
```

### <a name="NumberOfPerceivedObjects"></a>NumberOfPerceivedObjects

Number of Perceived Objects
A data element for representing the total number of detected and shared objects of an ITS-S
transmitting a CPM.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_



```asn1
NumberOfPerceivedObjects ::= INTEGER (0..255)
```

### <a name="SensorType"></a>SensorType

Sensor Type
Describes the type of attached sensor
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_

Values:
* **undefined** (0)<br>
* **radar** (1)<br>
* **lidar** (2)<br>
* **monovideo** (3)<br>
* **stereovision** (4)<br>
* **nightvision** (5)<br>
* **ultrasonic** (6)<br>
* **pmd** (7)<br>
* **fusion** (8)<br>
   object information provided from sensor data fusion system
* **inductionloop** (9)<br>
* **sphericalCamera** (10)<br>
* **itssaggregation** (11)    <br>
   object information gathered from other received ITS messages
```asn1
SensorType ::= INTEGER {
    undefined       (0),
    radar           (1),
    lidar           (2),
    monovideo       (3),
    stereovision    (4),
    nightvision     (5),
    ultrasonic      (6),
    pmd             (7),
    fusion          (8),    
    inductionloop   (9),
    sphericalCamera (10),
    itssaggregation (11)    
} (0..15)
```

### <a name="SegmentCount"></a>SegmentCount

Segment Count
A data element for representing either the total number of generated segments by the transmitter
or the identification of the received message segment.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _n/a_



```asn1
SegmentCount ::= INTEGER( 1..127)
```

### <a name="SpeedValueExtended"></a>SpeedValueExtended

Speed Value Extended
Value of a speed component.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m/s_

Values:
* **negativeSpeedMaximum** (-16383)<br>
   shall be set for values equal to or smaller than -163,83 m/s
* **standstill** (0)<br>
* **oneCentimeterPerSec** (1)<br>
* **speedMaximum** (16382)<br>
   shall be set for values equal to or greater than 163,82 m/s
* **unavailable** (16383)  <br>
   shall be set if information is not available
```asn1
SpeedValueExtended ::= INTEGER {
    negativeSpeedMaximum   (-16383), 
    standstill             (0),
    oneCentimeterPerSec    (1),
    speedMaximum           (16382), 
    unavailable            (16383)  
} (-16383..16383)
```

### <a name="AccelerationValue"></a>AccelerationValue

Acceleration Value
Value of an acceleration component.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,1 m/s2_

Values:
* **pointOneMeterPerSecSquared** (1)<br>
* **minusPointOneMeterPerSecSquared** (-1)<br>
* **unavailable** (161)  <br>
   shall be set if information is not available
```asn1
AccelerationValue ::= INTEGER {
    pointOneMeterPerSecSquared          (1),
    minusPointOneMeterPerSecSquared (-1),
    unavailable                                     (161)  
} (-160 .. 161)
```

### <a name="TimeOfMeasurement"></a>TimeOfMeasurement

Time of Measurement
Time difference with respect to the @see generationDeltaTime for the provided measurement for the
object. Negative values indicate that the provided object state refers to a point in time after
the @see generationDeltaTime has been computed, i.e. after the latest disseminating ITS-S
position update which is used to calculate the generationDeltaTime.
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _1 ms_

Values:
* **oneMilliSecond** (1)<br>
```asn1
TimeOfMeasurement ::= INTEGER {
    oneMilliSecond  (1)
} (-1500..1500)
```

### <a name="XSensorOffset"></a>XSensorOffset

X Sensor Offset
Describes the mounting position of a sensor along the negative x-direction from Reference Point
indicated by the @see refPointID
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **negativeZeroPointZeroOneMeter** (-1)<br>
* **negativeOneMeter** (-100)<br>
* **negativeOutOfRange** (-3094)<br>
* **positiveOneMeter** (100)<br>
* **positiveOutOfRange** (1001)<br>
```asn1
XSensorOffset ::= INTEGER {
    negativeZeroPointZeroOneMeter   (-1),
    negativeOneMeter                (-100),
    negativeOutOfRange              (-3094),
    positiveOneMeter                (100),
    positiveOutOfRange              (1001)
} (-3094..1001)
```

### <a name="YSensorOffset"></a>YSensorOffset

Y Sensor Offset
Described the mounting position of a sensor in y-direction from Reference Point
indicated by the @see refPointID
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
```asn1
YSensorOffset ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100)
} (-1000..1000)
```

### <a name="ZSensorOffset"></a>ZSensorOffset

Z Sensor Offset
Described the mounting position of a sensor in y-direction from Reference Point
indicated by the @see refPointID
<br>&nbsp;&nbsp;&nbsp;&nbsp;**Unit**: _0,01 m_

Values:
* **zeroPointZeroOneMeter** (1)<br>
* **oneMeter** (100)<br>
```asn1
ZSensorOffset ::= INTEGER {
    zeroPointZeroOneMeter   (1),
    oneMeter                (100)
} (0..1000)
```



