# ASN.1 module CPM-PDU-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) cpm (1) version1 (1) }_
 Specification of the Collective Perception Message ETSI TS 103 324
 Latest version available at https://forge.etsi.org/rep/ITS/CPM_TS103324

## Imports:
 * **[ITS-Container](ITS-Container.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (102894) cdd (2) version (2) }*<br/>
   Include ETSI TS 102 894-2 v1.3.1
   Include references from https://forge.etsi.org/rep/ITS/asn1/cdd_ts102894_2/blob/v1.3.1/ITS-Container.asn

 * **[CAM-PDU-Descriptions](CAM-PDU-Descriptions.md)** *{itu-t(0) identified-organization(4) etsi(0) itsDomain(5) wg1(1) en(302637) cam(2) version(2)}*<br/>
   Include ETSI EN 302 637-2 v1.4.1
   Include references from https://forge.etsi.org/rep/ITS/asn1/cam_en302637_2/blob/v1.4.1/CAM-PDU-Descriptions.asn

 * **[CPM-CommonDataTypes-Descriptions](CPM-CommonDataTypes-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) commonDataTypes (2) version1 (1)}*<br/>

 * **[CPM-OriginatingStationData-Descriptions](CPM-OriginatingStationData-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) originatingStationData (3) version1 (1)}*<br/>
    Import Originating Vehicle Container

 * **[CPM-SensorInformation-Descriptions](CPM-SensorInformation-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) sensorInformation (4) version1 (1)}*<br/>
    Import Sensor Information Container

 * **[CPM-PerceivedObject-Descriptions](CPM-PerceivedObject-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) perceivedObject (5) version1 (1)}*<br/>

 * **[CPM-FreeSpaceAddendum-Descriptions](CPM-FreeSpaceAddendum-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) freeSpaceAddendum (6) version1 (1)}*<br/>

## Data Elements:
### <a name="CPM-STATIONDATA-ID-AND-TYPE"></a>CPM-STATIONDATA-ID-AND-TYPE

 Information Object Class Definitions


```asn1
CPM-STATIONDATA-ID-AND-TYPE ::= CLASS {
    &id     CpmStationDataId UNIQUE,
    &Type
} WITH SYNTAX {&Type IDENTIFIED BY &id}
```

### <a name="CpmStationDataContainer"></a>CpmStationDataContainer

Fields:
* containerId [**CPM-STATIONDATA-ID-AND-TYPE**](#CPM-STATIONDATA-ID-AND-TYPE) .&id( {Set} )<br>
* containerData [**CPM-STATIONDATA-ID-AND-TYPE**](#CPM-STATIONDATA-ID-AND-TYPE) .&Type( {Set}{@containerId} )<br>
```asn1
CpmStationDataContainer {CPM-STATIONDATA-ID-AND-TYPE : Set} ::= SEQUENCE {
   containerId     CPM-STATIONDATA-ID-AND-TYPE.&id( {Set} ),
   containerData   CPM-STATIONDATA-ID-AND-TYPE.&Type( {Set}{@containerId} )
}
```

### <a name="CPM-CONTAINER-ID-AND-TYPE"></a>CPM-CONTAINER-ID-AND-TYPE

```asn1
CPM-CONTAINER-ID-AND-TYPE ::= CLASS {
    &id     CpmContainerId UNIQUE,
    &Type
} WITH SYNTAX {&Type IDENTIFIED BY &id}
```

### <a name="CpmPerceptionDataContainer"></a>CpmPerceptionDataContainer

Fields:
* containerId [**CPM-CONTAINER-ID-AND-TYPE**](#CPM-CONTAINER-ID-AND-TYPE) .&id( {Set} )<br>
* containerData [**CPM-CONTAINER-ID-AND-TYPE**](#CPM-CONTAINER-ID-AND-TYPE) .&Type( {Set}{@containerId} )<br>
```asn1
CpmPerceptionDataContainer {CPM-CONTAINER-ID-AND-TYPE : Set} ::= SEQUENCE {
   containerId     CPM-CONTAINER-ID-AND-TYPE.&id( {Set} ),
   containerData   CPM-CONTAINER-ID-AND-TYPE.&Type( {Set}{@containerId} )
}
```

### <a name="CpmStationDataId"></a>CpmStationDataId

```asn1
CpmStationDataId ::= INTEGER (0..255)
CpmContainerId ::= INTEGER (0..255)
```

### <a name="OriginatingStationData"></a>OriginatingStationData



```asn1
OriginatingStationData CPM-STATIONDATA-ID-AND-TYPE ::= {
    {OriginatingVehicleContainer IDENTIFIED BY originatingStationVehicleContainer} |
    {OriginatingRSUContainer IDENTIFIED BY originatingStationRSUContainer},
    ...
}
```

### <a name="PerceptionData"></a>PerceptionData

```asn1
PerceptionData CPM-CONTAINER-ID-AND-TYPE ::= {
    {SensorInformationContainer IDENTIFIED BY sensorInformationCpmContainer} |
    {PerceivedObjectContainer IDENTIFIED BY perceivedObjectCpmContainer} |
    {FreeSpaceAddendumContainer IDENTIFIED BY freeSpaceAdddendumCpmContainer},
    ...
}
```



```asn1
originatingStationVehicleContainer CpmStationDataId ::= 1
originatingStationRSUContainer CpmStationDataId ::= 2
```



```asn1
sensorInformationCpmContainer CpmContainerId ::= 1
perceivedObjectCpmContainer CpmContainerId ::= 2
freeSpaceAdddendumCpmContainer CpmContainerId ::= 3
```

### <a name="CPM"></a>CPM

 Collective Perception Message
Collective Perception Message Root
This DF includes DEs for the CPM protocolVersion, the CP message type identifier _messageID_ and
the station identifier _stationID_ of the originating ITS-S.

Fields:
* header [**ItsPduHeader**](ITS-Container.md#ItsPduHeader) <br>

   The DE _protocolVersion_ is used to select the appropriate protocol decoder at the receiving
   ITS-S. It shall be set to @todo cpm(15).
   The DE _messageID_ shall be harmonized with other V2X message identifier definitions.
   
* cpm [**CollectivePerceptionMessage**](#CollectivePerceptionMessage) <br>
```asn1
CPM ::= SEQUENCE {
        header ItsPduHeader,
    cpm CollectivePerceptionMessage
}
```

### <a name="CollectivePerceptionMessage"></a>CollectivePerceptionMessage

Collective Perception Message
This is the actual CPM Payload. It shall include the time stamp of the CPM and the applicable
containers of type _PerceptionData_. The selection of the StationDataContainer type container
depends on the _StationType_ as selected in the @see CpmManagementContainer

Fields:
* generationDeltaTime [**GenerationDeltaTime**](CAM-PDU-Descriptions.md#GenerationDeltaTime) <br>
* cpmParameters [**CpmParameters**](#CpmParameters) <br>
```asn1
CollectivePerceptionMessage ::= SEQUENCE {
    generationDeltaTime GenerationDeltaTime,
    cpmParameters       CpmParameters
}
```

### <a name="CpmParameters"></a>CpmParameters

CPM Parameters
The sequence of mandatory and optional containers. Other containers may be added in the future.

Fields:
* managementContainer [**CpmManagementContainer**](#CpmManagementContainer) <br>
   managementContainer
   The managementContainer comprises basic information about the originating ITS-S, which are
   not specific to vehicles or RSUs.
   
* stationDataContainer [**CpmStationDataContainer**](#CpmStationDataContainer)  {{OriginatingStationData}} OPTIONAL<br>
   stationDataContainer
   The stationDataContainer comprises ITS-S type specific information about the sending station.
   
* perceptionData **SEQUENCE**  SIZE(1..255) OF CpmPerceptionDataContainer {{PerceptionData}} OPTIONAL<br>
   perceptionData
   The perceptionData comprises different container types for describing the sensory properties
   of the transmitting ITS-S, its detected objects and free space estimates.
   
```asn1
CpmParameters ::= SEQUENCE {
        managementContainer     CpmManagementContainer,
        stationDataContainer    CpmStationDataContainer {{OriginatingStationData}} OPTIONAL,
        perceptionData          SEQUENCE SIZE(1..255) OF CpmPerceptionDataContainer {{PerceptionData}} OPTIONAL,
    ...
}
```

### <a name="CpmManagementContainer"></a>CpmManagementContainer

CPM Management Container
The managementContainer comprises basic information about the originating ITS-S, which are not
specific to vehicles or RSUs.

Fields:
* stationType [**StationType**](ITS-Container.md#StationType) <br>
* messageSegmentInfo [**MessageSegmentInfo**](CPM-CommonDataTypes-Descriptions.md#MessageSegmentInfo)  OPTIONAL<br>
   messageSegmentInfo
   The perceived object container segment info describes the segmentation information in case
   the data for CPM transmission needs to be split up into multiple messages due to
   message size constraints.
   
* referencePosition [**ReferencePosition**](ITS-Container.md#ReferencePosition) <br>
```asn1
CpmManagementContainer ::= SEQUENCE {
    stationType                             StationType,
        messageSegmentInfo     MessageSegmentInfo OPTIONAL,
    referencePosition      ReferencePosition,
    ...
}
```



