# ASN.1 module CPM-PerceivedObject-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) perceivedObject (5) version1 (1) }_

## Imports:
 * **[CPM-CommonDataTypes-Descriptions](CPM-CommonDataTypes-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) commonDataTypes (2) version1 (1)}*<br/>

## Data Elements:
### <a name="PerceivedObjectContainer"></a>PerceivedObjectContainer

Perceived Object Container
A list of perceived objects. Each object shall be described as defined in @see PerceivedObject.

Fields:
* numberOfPerceivedObjects [**NumberOfPerceivedObjects**](CPM-CommonDataTypes-Descriptions.md#NumberOfPerceivedObjects)  DEFAULT 0<br>

   The total number of detected objects by the station at the time of generating the message.
   Due to the dynamic message generation rules, this number does not have to reflect the number
   of objects included in this message but states the number of objects known to the sender at
   the time of generating the message.
   
* perceivedObjects **SEQUENCE**  SIZE(1..128, ...) OF PerceivedObject<br>
```asn1
PerceivedObjectContainer ::= SEQUENCE {
        numberOfPerceivedObjects    NumberOfPerceivedObjects DEFAULT 0,
    perceivedObjects            SEQUENCE SIZE(1..128, ...) OF PerceivedObject
}
```

### <a name="PerceivedObject"></a>PerceivedObject

Perceived Object
An object in the context of the CP Service refers to the kinematic and attitude representation of
a detected object within a sensor’s perception range. An object may be reported directly by a
sensor or a sensor fusion system.

Fields:
* objectID [**Identifier**](CPM-CommonDataTypes-Descriptions.md#Identifier) <br>

   Identifier assigned to a detected object which remains constant as long as the object is
   perceived by the disseminating ITS-S. Numbers are assigned in an increasing round-robin
   fashion. When the last identifier in the allowed range has been used, the first counter for
   the identifier starts from the beginning of the range again.
   
* timeOfMeasurement [**TimeOfMeasurement**](CPM-CommonDataTypes-Descriptions.md#TimeOfMeasurement) <br>

   Provides the time difference from the message’s generation delta time to the time of the
   measurement of the object.
   
* xDistance [**ObjectDistance**](CPM-CommonDataTypes-Descriptions.md#ObjectDistance) <br>

   Distance to detected object from the ITS-S's reference point in x-direction for the time
   of measurement. For a vehicle, the distance is reported in a body-fixed coordinate system
   as provided by ISO 8855. For a RSU, the distance is reported in a coordinate system in which
   the y-axis corresponds to the North direction, the x-axis to the East direction, and the z-
   axis to the vertical direction.
   
* yDistance [**ObjectDistance**](CPM-CommonDataTypes-Descriptions.md#ObjectDistance) <br>

   Distance to detected object from the ITS-S's reference point in y-direction for the time
   of measurement. For a vehicle, the distance is reported in a body-fixed coordinate system
   as provided by ISO 8855. For a RSU, the distance is reported in a coordinate system in which
   the y-axis corresponds to the North direction, the x-axis to the East direction, and the z-
   axis to the vertical direction
   
* zDistance [**ObjectDistance**](CPM-CommonDataTypes-Descriptions.md#ObjectDistance)  OPTIONAL<br>

   Distance to detected object from the ITS-S's reference point in z-direction for the time
   of measurement. For a vehicle, the distance is reported in a body-fixed coordinate system
   as provided by ISO 8855. For a RSU, the distance is reported in a coordinate system in which
   the y-axis corresponds to the North direction, the x-axis to the East direction, and the z-
   axis to the vertical direction
   
* xSpeed [**SpeedExtended**](CPM-CommonDataTypes-Descriptions.md#SpeedExtended) <br>

   Speed of the detected object in the detecting ITS-S’s reference system in x-direction for the
   time of measurement (i.e. speed of the object relative to the origin of the station’s reference
   system). For a vehicle, the speed is reported in a body-fixed coordinate system as provided by
   ISO 8855 originating at the ITS-station’s reference point. For a RSU, the speed is reported in
   a coordinate system in which the y-axis corresponds to the North direction, the x-axis to the
   East direction, and the z-axis to the vertical direction.
   
* ySpeed [**SpeedExtended**](CPM-CommonDataTypes-Descriptions.md#SpeedExtended) <br>

   Speed of the detected object in the detecting ITS-S’s reference system in y-direction for the
   time of measurement (i.e. speed of the object relative to the origin of the station’s reference
   system). For a vehicle, the speed is reported in a body-fixed coordinate system as provided by
   ISO 8855 originating at the ITS-station’s reference point. For a RSU, the speed is reported in
   a coordinate system in which the y-axis corresponds to the North direction, the x-axis to the
   East direction, and the z-axis to the vertical direction.
   
* zSpeed [**SpeedExtended**](CPM-CommonDataTypes-Descriptions.md#SpeedExtended)  OPTIONAL<br>

   Speed of the detected object in the detecting ITS-S’s reference system in z-direction for the
   time of measurement (i.e. speed of the object relative to the origin of the station’s reference
   system). For a vehicle, the speed is reported in a body-fixed coordinate system as provided by
   ISO 8855 originating at the ITS-station’s reference point. For a RSU, the speed is reported in
   a coordinate system in which the y-axis corresponds to the North direction, the x-axis to the
   East direction, and the z-axis to the vertical direction.
   
* xAcceleration [**Acceleration**](CPM-CommonDataTypes-Descriptions.md#Acceleration)  OPTIONAL<br>

   Acceleration of the detected object from the ITS-S's reference point in x-direction
   for the time of measurement. For a vehicle, the acceleration is reported in a body-fixed
   coordinate system as provided by ISO 8855 originating at the ITS-station’s reference point.
   For a RSU, the acceleration is reported in a coordinate system in which the y-axis corresponds
   to the North direction, the x-axis to the East direction, and the z-axis to the vertical direction.
   
* yAcceleration [**Acceleration**](CPM-CommonDataTypes-Descriptions.md#Acceleration)  OPTIONAL<br>

   Acceleration of the detected object from the ITS-S's reference point in y-direction
   for the time of measurement. For a vehicle, the acceleration is reported in a body-fixed
   coordinate system as provided by ISO 8855 originating at the ITS-station’s reference point.
   For a RSU, the acceleration is reported in a coordinate system in which the y-axis corresponds
   to the North direction, the x-axis to the East direction, and the z-axis to the vertical direction.
   
* zAcceleration [**Acceleration**](CPM-CommonDataTypes-Descriptions.md#Acceleration)  OPTIONAL<br>

   Acceleration of the detected object from the ITS-S's reference point in z-direction
   for the time of measurement. For a vehicle, the acceleration is reported in a body-fixed
   coordinate system as provided by ISO 8855 originating at the ITS-station’s reference point.
   For a RSU, the acceleration is reported in a coordinate system in which the y-axis corresponds
   to the North direction, the x-axis to the East direction, and the z-axis to the vertical direction.
   
* rollAngle [**CartesianAngle**](CPM-CommonDataTypes-Descriptions.md#CartesianAngle)  OPTIONAL<br>

   Roll angle of object from the ITS-S's reference point. For a vehicle, the angle is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angle is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angle is measured with positive values considering the object orientation turning
   counter-clockwise around the x-axis.
   
* pitchAngle [**CartesianAngle**](CPM-CommonDataTypes-Descriptions.md#CartesianAngle)  OPTIONAL<br>

   Pitch angle of object from the ITS-S's reference point. For a vehicle, the angle is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angle is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angle is measured with positive values considering the object orientation turning
   counter-clockwise around the y-axis.
   
* yawAngle [**CartesianAngle**](CPM-CommonDataTypes-Descriptions.md#CartesianAngle)  OPTIONAL<br>

   Yaw angle of object from the ITS-S's reference point. For a vehicle, the angle is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angle is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angle is measured with positive values considering the object orientation turning
   counter-clockwise around the z-axis.
   
* rollRate [**CartesianAngularSpeed**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularSpeed)  OPTIONAL<br>

   Roll rate of object from the ITS-S's reference point. For a vehicle, the angular rate is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular rate is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular rate is measured with positive values considering the object orientation turning
   counter-clockwise around the x-axis.
   
* pitchRate [**CartesianAngularSpeed**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularSpeed)  OPTIONAL<br>

   Pitch rate of object from the ITS-S's reference point. For a vehicle, the angular rate is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular rate is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular rate is measured with positive values considering the object orientation turning
   counter-clockwise around the y-axis.
   
* yawRate [**CartesianAngularSpeed**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularSpeed)  OPTIONAL<br>

   Yaw rate of object from the ITS-S's reference point. For a vehicle, the angular rate is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular rate is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular rate is measured with positive values considering the object orientation turning
   counter-clockwise around the z-axis.
   
* rollAcceleration [**CartesianAngularAcceleration**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularAcceleration)  OPTIONAL<br>

   Roll acceleration of object from the ITS-S's reference point. For a vehicle, the angular acceleration is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular acceleration is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular acceleration is measured with positive values considering the object orientation turning
   counter-clockwise around the x-axis.
   
* pitchAcceleration [**CartesianAngularAcceleration**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularAcceleration)  OPTIONAL<br>

   Pitch acceleration of object from the ITS-S's reference point. For a vehicle, the angular acceleration is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular acceleration is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular acceleration is measured with positive values considering the object orientation turning
   counter-clockwise around the y-axis.
   
* yawAcceleration [**CartesianAngularAcceleration**](CPM-CommonDataTypes-Descriptions.md#CartesianAngularAcceleration)  OPTIONAL<br>

   Yaw acceleration of object from the ITS-S's reference point. For a vehicle, the angular acceleration is
   reported in a body-fixed coordinate system as provided by ISO 8855 originating at the ITS-station’s
   reference point. For a RSU, the angular acceleration is reported in a coordinate system in which the y-axis
   corresponds to the North direction, the x-axis to the East direction, and the z- axis to the vertical direction.
   The angular acceleration is measured with positive values considering the object orientation turning
   counter-clockwise around the z-axis.
   
* lowerTriangularCorrelationMatrixColumns [**LowerTriangularPositiveSemidefiniteMatrix**](CPM-CommonDataTypes-Descriptions.md#LowerTriangularPositiveSemidefiniteMatrix)  OPTIONAL<br>

   Provides the columns of a lower triangular positive semi definite correlation matrix for the
   kinematic state and attitude space provided for this object.
   The order of the columns and rows of the correlation matrix is as follows:
   - xDistance
   - yDistance
   - zDistance
   - xSpeed
   - ySpeed
   - zSpeed
   - xAcceleration
   - yAcceleration
   - zAcceleration
   - rollAngle
   - pitchAngle
   - yawAngle
   - rollRate
   - pitchRate
   - yawRate
   - rollAcceleration
   - pitchAcceleration
   - yawAcceleration
   The number of lowerTriangularCorrelationMatrixColumns to be included "k" is thereby the number of provided
   values "n" of the kinematic state and attitude space minus 1: k = n-1.
   Each column "i" of the lowerTriangularCorrelationMatrixColumns contains k-(i-1) values.
   In case certain values of the kinematic state and attitude space are not provided, they are omitted from
   the lowerTriangularCorrelationMatrixColumns.
   
* planarObjectDimension1 [**ObjectDimension**](CPM-CommonDataTypes-Descriptions.md#ObjectDimension)  OPTIONAL<br>

   First dimension of object as provided by the sensor or environment model. This dimension is
   always contained in the plane which is oriented perpendicular to the direction of the angle
   indicated by the yawAngle and which contains the object's reference point.
   
* planarObjectDimension2 [**ObjectDimension**](CPM-CommonDataTypes-Descriptions.md#ObjectDimension)  OPTIONAL<br>

   Second dimension of the object as provided by the sensor environment model. This dimension is
   contained in the plane oriented in the direction of the angle indicated by the yawAngle and
   the object's reference point.
   
* verticalObjectDimension [**ObjectDimension**](CPM-CommonDataTypes-Descriptions.md#ObjectDimension)  OPTIONAL<br>

   Vertical dimension of object as provided by the sensor or object model.
   
* objectRefPoint [**ObjectRefPoint**](CPM-CommonDataTypes-Descriptions.md#ObjectRefPoint)  DEFAULT 0<br>

   The reference point on the perceived object. The kinematic attitude and state data provided
   for this object are valid for this reference point of the object. In case no object reference
   point can be determined, it is assumed to be the center point of the detected object.
   
* objectAge [**ObjectAge**](CPM-CommonDataTypes-Descriptions.md#ObjectAge) <br>

   Provides the age of the detected and described object.
   
* objectConfidence [**ObjectConfidence**](CPM-CommonDataTypes-Descriptions.md#ObjectConfidence)  OPTIONAL<br>

   The confidence associated to the object. The computation of the object confidence is based on a sensor's or
   fusion system's specific detection confidence, the binary detection success that is, if an object
   has been successfully detected by the last measurement and the object age.
   
* sensorIDList [**SensorIdList**](CPM-CommonDataTypes-Descriptions.md#SensorIdList)  OPTIONAL<br>

   List of sensor-IDs which provided the measurement data. Refers to the sensorID in the
   @see SensorInformationContainer.
   If the @see SensorInformationContainer is never provided by the disseminating ITS-S, the list shall be
   populated with random numbers, where each number is assigned to a sensor of the transmitting station.
   
* dynamicStatus [**DynamicStatus**](CPM-CommonDataTypes-Descriptions.md#DynamicStatus)  OPTIONAL<br>

   Indicated the dynamic capabilities of a detected object.
   
* classification [**ObjectClassDescription**](CPM-CommonDataTypes-Descriptions.md#ObjectClassDescription)  OPTIONAL<br>

   Provides the classification of the described object. Multi-dimensional classification may be
   provided.
   
* matchedPosition [**MatchedPosition**](CPM-CommonDataTypes-Descriptions.md#MatchedPosition)  OPTIONAL<br>

   The optional map-matched position of an object. This requires that a MAP-message is provided.
   
```asn1
PerceivedObject ::= SEQUENCE {
        objectID                Identifier,
        timeOfMeasurement       TimeOfMeasurement,
        xDistance               ObjectDistance,
        yDistance               ObjectDistance,
        zDistance               ObjectDistance OPTIONAL,
        xSpeed                  SpeedExtended,
        ySpeed                  SpeedExtended,
        zSpeed                  SpeedExtended OPTIONAL,
        xAcceleration           Acceleration OPTIONAL,
        yAcceleration           Acceleration OPTIONAL,
        zAcceleration           Acceleration OPTIONAL,
        rollAngle                CartesianAngle OPTIONAL,
        pitchAngle                CartesianAngle OPTIONAL,
        yawAngle                CartesianAngle OPTIONAL,
        rollRate                CartesianAngularSpeed OPTIONAL,
        pitchRate                CartesianAngularSpeed OPTIONAL,
        yawRate                CartesianAngularSpeed OPTIONAL,
        rollAcceleration                CartesianAngularAcceleration OPTIONAL,
        pitchAcceleration                CartesianAngularAcceleration OPTIONAL,
        yawAcceleration                CartesianAngularAcceleration OPTIONAL,
        lowerTriangularCorrelationMatrixColumns       LowerTriangularPositiveSemidefiniteMatrix OPTIONAL,
        planarObjectDimension1  ObjectDimension OPTIONAL,
        planarObjectDimension2  ObjectDimension OPTIONAL,
        verticalObjectDimension ObjectDimension OPTIONAL,
        objectRefPoint          ObjectRefPoint DEFAULT 0,
        objectAge               ObjectAge,
        objectConfidence        ObjectConfidence OPTIONAL,
        sensorIDList            SensorIdList OPTIONAL,
        dynamicStatus           DynamicStatus OPTIONAL,
        classification          ObjectClassDescription OPTIONAL,
        matchedPosition         MatchedPosition OPTIONAL,
    ...
}
```



