# ASN.1 module CPM-SensorInformation-Descriptions
 OID: _{ itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) sensorInformation (4) version1 (1) }_

## Imports:
 * **[CPM-CommonDataTypes-Descriptions](CPM-CommonDataTypes-Descriptions.md)** *{itu-t (0) identified-organization (4) etsi (0) itsDomain (5) wg1 (1) ts (103324) commonDataTypes (2) version1 (1)}*<br/>

## Data Elements:
### <a name="SensorInformationContainer"></a>SensorInformationContainer

Sensor Information Container
This container contains a list of sensor-types or data fusion systems from which the station
provides information about detected objects.


```asn1
SensorInformationContainer ::= SEQUENCE SIZE(1..128, ...) OF SensorInformation
```

### <a name="SensorInformation"></a>SensorInformation

Fields:
* sensorID [**Identifier**](CPM-CommonDataTypes-Descriptions.md#Identifier) <br>

   Sensor pseudonym ID used to relate which measurement has been received by which sensor.
   This ID is referred to in the @see PerceivedObject.
   
* type [**SensorType**](CPM-CommonDataTypes-Descriptions.md#SensorType) <br>
* detectionArea [**DetectionArea**](#DetectionArea) <br>
* freeSpaceConfidence [**FreeSpaceConfidence**](CPM-CommonDataTypes-Descriptions.md#FreeSpaceConfidence)  OPTIONAL<br>

   Describes the isotropic free space confidence that can be assumed for the entire detection
   area of this sensor. Shadowed areas can be derived from provided objects. Deviations from
   this free space derivation can be expressed in the @see FreeSpaceAddendumContainer.
   
```asn1
SensorInformation ::= SEQUENCE {
        sensorID          		Identifier,
    type        		    SensorType,
    detectionArea		    DetectionArea,
        freeSpaceConfidence		FreeSpaceConfidence OPTIONAL,
   ...
}
```

### <a name="DetectionArea"></a>DetectionArea

Detection Area
Choice of DFs to detail the sensor information.

Fields:
* vehicleSensor [**VehicleSensor**](#VehicleSensor) <br>

   The _vehicleSensor_ shall be used for describing non-stationary sensors attached to vehicles.
   
* stationarySensorRadial [**AreaRadial**](CPM-CommonDataTypes-Descriptions.md#AreaRadial) <br>

   The _stationarySensorRadial_ can be used to provide details for describing sensors mounted to
   road-side units
   
* stationarySensorPolygon [**AreaPolygon**](CPM-CommonDataTypes-Descriptions.md#AreaPolygon) <br>

   The _stationarySensorPolygon_ can be used to describe a polygonal detection area associated
   to a single sensor or to describe the union of multiple polygonal areas expressed as one
   combined polygon.
   
* stationarySensorCircular [**AreaCircular**](CPM-CommonDataTypes-Descriptions.md#AreaCircular) <br>

   The _stationarySensorCircular_ describes a circular perception area for a stationary sensor.
   The position offset refers to the center point of the circular area.
   
* stationarySensorEllipse [**AreaEllipse**](CPM-CommonDataTypes-Descriptions.md#AreaEllipse) <br>

   The _stationarySensorEllipse_ describes an ellipse-shaped perception area for a stationary
   sensor.The position offset refers to the center point of the ellipse.
   
* stationarySensorRectangle [**AreaRectangle**](CPM-CommonDataTypes-Descriptions.md#AreaRectangle) <br>

   The _stationarySensorRectangle_ describes a rectangle as a perception area for a stationary
   sensor. The position offset refers to the center point of the rectangle.
   
```asn1
DetectionArea ::= CHOICE {
        vehicleSensor               VehicleSensor,
        stationarySensorRadial      AreaRadial,
        stationarySensorPolygon     AreaPolygon,
        stationarySensorCircular    AreaCircular,
        stationarySensorEllipse     AreaEllipse,
        stationarySensorRectangle   AreaRectangle,
    ...
}
```

### <a name="VehicleSensor"></a>VehicleSensor

Vehicle Sensor
Describes the perception capabilities of mobile sensors mounted to vehicles.

Fields:
* refPointId [**RefPointId**](CPM-CommonDataTypes-Descriptions.md#RefPointId)  DEFAULT 0<br>

   An identification of the reference point in case of a sensor mounted to trailer.
   Defaults to ITS ReferencePoint (0).
   
* xSensorOffset [**XSensorOffset**](CPM-CommonDataTypes-Descriptions.md#XSensorOffset) <br>

   Mounting position of sensor in negative x-direction from Reference Point indicated by the @see refPointId.
   
* ySensorOffset [**YSensorOffset**](CPM-CommonDataTypes-Descriptions.md#YSensorOffset) <br>

   Mounting position of sensor in y-direction from Reference Point indicated by the @see refPointId.
   
* zSensorOffset [**ZSensorOffset**](CPM-CommonDataTypes-Descriptions.md#ZSensorOffset)  OPTIONAL<br>

   Mounting position of sensor in z-direction from Reference Point indicated by the @see refPointId.
   
* vehicleSensorPropertyList [**VehicleSensorPropertyList**](#VehicleSensorPropertyList) <br>

   The actual extension of the area covered by the specific vehicle sensor. In case of multiple
   perception areas for a sensor, a list of areas covered by this sensor can be added.
   
```asn1
VehicleSensor ::= SEQUENCE {
        refPointId                      RefPointId DEFAULT 0,
        xSensorOffset                   XSensorOffset,
        ySensorOffset                   YSensorOffset,
        zSensorOffset                   ZSensorOffset OPTIONAL,
        vehicleSensorPropertyList       VehicleSensorPropertyList,
    ...
}
```

### <a name="VehicleSensorPropertyList"></a>VehicleSensorPropertyList

 Vehicle Sensor Property List


```asn1
VehicleSensorPropertyList ::= SEQUENCE SIZE(1..10) OF VehicleSensorProperties
```

### <a name="VehicleSensorProperties"></a>VehicleSensorProperties

Vehicle Sensor Properties
The actual extension of the area covered by the specific vehicle sensor. In case of multiple
perception areas for a sensor, a list of areas covered by this sensor can be added.

Fields:
* range [**Range**](CPM-CommonDataTypes-Descriptions.md#Range) <br>
* horizontalOpeningAngleStart [**CartesianAngleValue**](CPM-CommonDataTypes-Descriptions.md#CartesianAngleValue) <br>
* horizontalOpeningAngleEnd [**CartesianAngleValue**](CPM-CommonDataTypes-Descriptions.md#CartesianAngleValue) <br>
* verticalOpeningAngleStart [**CartesianAngleValue**](CPM-CommonDataTypes-Descriptions.md#CartesianAngleValue)  OPTIONAL<br>
* verticalOpeningAngleEnd [**CartesianAngleValue**](CPM-CommonDataTypes-Descriptions.md#CartesianAngleValue)  OPTIONAL<br>
```asn1
VehicleSensorProperties ::= SEQUENCE {
    range                           Range,
    horizontalOpeningAngleStart     CartesianAngleValue,
    horizontalOpeningAngleEnd       CartesianAngleValue,
    verticalOpeningAngleStart       CartesianAngleValue OPTIONAL,
    verticalOpeningAngleEnd         CartesianAngleValue OPTIONAL,
    ...
}
```



